#!/usr/bin/python
# EXAMPLE SNAKE PLUGINS
#
# Copyright 2007 Red Hat, Inc.
#
# This software may be freely redistributed under the terms of the GNU
# general public license.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
#

# All plugins have the same function definition: def plugin(item,**context)
# 'context' will be a dict that is guaranteed to contain at least the following
# three items:
#  'machine' - a snake.machine.Machine object defining the target machine
#  'tree'    - a snake.tree.Tree object defining the tree to be installed
#  'server   - the "config" dict from snake-server, containing the server config
# Future versions of snake-server might add more data.
# 'item' depends on the type of plugin. Currently there are two types of
# plugins used by snake-server: 
#  kernel_args_hook(args,**context): modifies the kernel commandline args list
#  kickstart_hook(ks,**context):     modifies the snake.Kickstart object
# Each function should modify the item it is given and return the modified
# version.
# Two example plugin functions are shown below.

# Example kernel_args_hook
def kernel_args_hook(args,**ctx):
    '''Trees built after a certain date are ipv6-capable, but ipv6 dhcp takes
    a really long time. Turn it off from the kernel commandline.'''
    if ctx['tree'].time > 1161112000:
        args.append('noipv6')
    return args

# Example kickstart_hook
def kickstart_hook(ks,**ctx):
    '''RHEL5 trees need the 'key' command in their kickstart.'''

    from pykickstart.constants import KS_INSTKEY_SKIP
    from pykickstart.version import RHEL5

    if ks.version == RHEL5 and not ks.key.key:
        '''unless already specified, skip the installation number prompt'''
        ks.key(key=KS_INSTKEY_SKIP)

